Various renames following the name change from "Runtime APEX" to "ART APEX".

In particular ANDROID_RUNTIME_ROOT is now ANDROID_ART_ROOT.

Test: Build & boot
Test: art/tools/run-gtests.sh in chroot
Test: art/test/testrunner/testrunner.py --target --64 in chroot
Test: art/tools/run-libcore-tests.sh --mode=device --variant=X64 in chroot
Test: art/tools/run-jdwp-tests.sh --mode=device --variant=X64 in chroot
Test: m test-art-host-gtest
Test: art/test/testrunner/testrunner.py --host --64
Test: art/tools/run-jdwp-tests.sh --mode=host
Bug: 135753770
Change-Id: Ia74da964e54cf396d66e9e12ea56da4e9483662a
diff --git a/libartbase/base/common_art_test.cc b/libartbase/base/common_art_test.cc
index e05c143..7101ca4 100644
--- a/libartbase/base/common_art_test.cc
+++ b/libartbase/base/common_art_test.cc
@@ -184,15 +184,15 @@
       setenv("ANDROID_I18N_ROOT", android_i18n_root.c_str(), 1);
     }
 
     // Environment variable ANDROID_RUNTIME_ROOT is set on the device, but not
     // necessarily on the host. It needs to be set so that various libraries
     // like libcore / icu4j / icu4c can find their data files.
-    const char* android_runtime_root_from_env = getenv("ANDROID_RUNTIME_ROOT");
-    if (android_runtime_root_from_env == nullptr) {
-      // Use ${ANDROID_HOST_OUT}/com.android.art for ANDROID_RUNTIME_ROOT.
-      std::string android_runtime_root = android_host_out_from_env;
-      android_runtime_root += "/com.android.art";
-      setenv("ANDROID_RUNTIME_ROOT", android_runtime_root.c_str(), 1);
+    const char* android_art_root_from_env = getenv("ANDROID_ART_ROOT");
+    if (android_art_root_from_env == nullptr) {
+      // Use ${ANDROID_HOST_OUT}/com.android.art for ANDROID_ART_ROOT.
+      std::string android_art_root = android_host_out_from_env;
+      android_art_root += "/com.android.art";
+      setenv("ANDROID_ART_ROOT", android_art_root.c_str(), 1);
     }
 
     // Environment variable ANDROID_TZDATA_ROOT is set on the device, but not
@@ -184,15 +184,15 @@
     }
 
-    // Environment variable ANDROID_RUNTIME_ROOT is set on the device, but not
+    // Environment variable ANDROID_ART_ROOT is set on the device, but not
     // necessarily on the host. It needs to be set so that various libraries
     // like libcore / icu4j / icu4c can find their data files.